@@ -19,6 +19,7 @@ from zou.app.services import (
     assets_service,
     base_service,
     breakdown_service,
+    deletion_service,
     entities_service,
     news_service,
     notifications_service,
@@ -78,14 +79,18 @@ def create_comment(
     files={},
     created_at="",
     links=[],
+    with_hashtags=True
 ):
     """
     Create a new comment and related: news, notifications and events.
     """
+    related_tasks = []
+    author = _get_comment_author(person_id)
     task = tasks_service.get_task(task_id, relations=True)
     task_status = tasks_service.get_task_status(task_status_id)
-    author = _get_comment_author(person_id)
+    task_type = tasks_service.get_task_type(task["task_type_id"])
     _check_retake_capping(task_status, task)
+
     comment = new_comment(
         task_id=task_id,
         object_type="Task",
@@ -97,6 +102,10 @@ def create_comment(
         created_at=created_at,
         links=links,
     )
+
+    if with_hashtags:
+        _handle_hashtags(author, task_type, task, text)
+
     task, status_changed = _manage_status_change(task_status, task, comment)
     _manage_subscriptions(task, comment, status_changed)
     comment["task_status"] = task_status
@@ -107,9 +116,32 @@ def create_comment(
     )
     for automation in status_automations:
         _run_status_automation(automation, task, person_id)
+
     return comment
 
 
+def _handle_hashtags(person, task_type, task, text):
+    hashtags = get_comment_hashtags(text)
+    if len(hashtags) > 0:
+        entity = entities_service.get_entity(entity_id=task["entity_id"])
+        tasks = entities_service.get_entity_tasks(entity)
+        tasks = filter_tasks_by_hashtags(tasks, hashtags, task_type)
+        if len(tasks) > 0:
+            for _task in tasks:
+                task_status = tasks_service.get_task_status(
+                    _task["task_status_id"]
+                )
+                create_comment(
+                    person_id=person["id"],
+                    task_id=_task["id"],
+                    text=text + f"\n\n____\nFrom {task_type['name']} task",
+                    task_status_id=task_status["id"],
+                    with_hashtags=False
+                )
+    return hashtags
+
+
+
 def _check_retake_capping(task_status, task):
     if task_status["is_retake"]:
         project = projects_service.get_project(task["project_id"])
@@ -271,9 +303,12 @@ def _run_status_automation(automation, task, person_id):
 
     elif automation["out_field_type"] == "ready_for":
         try:
-            asset = assets_service.update_asset(
-                task["entity_id"],
-                {"ready_for": automation["out_task_type_id"]},
+            data = {"ready_for": automation["out_task_type_id"]}
+            asset = assets_service.update_asset(task["entity_id"], data)
+            events.emit(
+                "asset:update",
+                {"asset_id": task["entity_id"], "data": data},
+                project_id=task["project_id"],
             )
             breakdown_service.refresh_casting_stats(asset)
         except AssetNotFoundException:
@@ -355,7 +390,7 @@ def reset_mentions(comment):
     return comment_dict
 
 
-def create_attachment(comment, uploaded_file, randomize=False):
+def create_attachment(comment, uploaded_file, randomize=False, reply_id=None):
     tmp_folder = current_app.config["TMP_DIR"]
     filename = uploaded_file.filename
     mimetype = uploaded_file.mimetype
@@ -366,11 +401,19 @@ def create_attachment(comment, uploaded_file, randomize=False):
         filename = f"{filename[:len(filename) - len(extension) - 1]}"
         filename += f"-{random_str}.{extension}"
 
+    if reply_id is not None:
+        is_reply_present = any(
+            reply["id"] == reply_id for reply in comment.get("replies", [])
+        )
+        if not is_reply_present:
+            reply_id = None
+
     attachment_file = AttachmentFile.create(
         name=filename,
         size=0,
         extension=extension,
         mimetype=mimetype,
+        reply_id=reply_id,
         comment_id=comment["id"],
     )
     attachment_file_id = str(attachment_file.id)
@@ -455,7 +498,7 @@ def _send_ack_event(project_id, comment, user_id, name="acknowledge"):
     )
 
 
-def reply_comment(comment_id, text, person_id=None):
+def reply_comment(comment_id, text, person_id=None, files={}):
     """
     Add a reply entry to the JSONB field of given comment model. Create
     notifications needed for this.
@@ -469,6 +512,7 @@ def reply_comment(comment_id, text, person_id=None):
     task = tasks_service.get_task(comment.object_id, relations=True)
     if comment.replies is None:
         comment.replies = []
+
     reply = {
         "id": str(fields.gen_uuid()),
         "date": date_helpers.get_now(),
@@ -483,18 +527,26 @@ def reply_comment(comment_id, text, person_id=None):
     replies = list(comment.replies)
     replies.append(reply)
     comment.update({"replies": replies})
+    comment_dict = comment.serialize(relations=True)
+    if len(files.keys()) > 0:
+        _, new_attachment_files = add_attachments_to_comment(
+            comment_dict, files, reply_id=reply["id"]
+        )
+        for new_attachment_file in new_attachment_files:
+            new_attachment_file["reply_id"] = reply["id"]
+        reply["attachment_files"] = new_attachment_files
     tasks_service.clear_comment_cache(comment_id)
     events.emit(
         "comment:reply",
         {
             "task_id": task["id"],
-            "comment_id": str(comment.id),
+            "comment_id": comment_id,
             "reply_id": reply["id"],
         },
         project_id=task["project_id"],
     )
     notifications_service.create_notifications_for_task_and_reply(
-        task, comment.serialize(), reply
+        task, comment_dict, reply
     )
     return reply
 
@@ -508,6 +560,14 @@ def get_reply(comment_id, reply_id):
 def delete_reply(comment_id, reply_id):
     comment = tasks_service.get_comment_raw(comment_id)
     task = tasks_service.get_task(comment.object_id)
+
+    if comment.attachment_files is None:
+        comment.attachment_files = []
+        for attachment_file in comment.attachment_files:
+            if attachment_file.reply_id == reply_id:
+                deletion_service.remove_attachment_file_by_id(
+                    attachment_file["id"]
+                )
     if comment.replies is None:
         comment.replies = []
     comment.replies = [
@@ -567,19 +627,64 @@ def get_comment_department_mention_ids(project_id, text):
     ]
 
 
-def add_attachments_to_comment(comment, files):
+def get_comment_hashtags(text):
+    """
+    Check for task type mentions (#full name) in text and returns matching 
+    tags. If all is present, return only all because it includes everything
+    else.
+    """
+    hashtags = [
+        hashtag[1:].lower()
+        for hashtag in re.findall("#[a-zA-Z]*", text, re.IGNORECASE)
+    ]
+    if "all" in hashtags:
+        return ["all"]
+    return list(set(hashtags))
+
+
+def filter_tasks_by_hashtags(tasks, hashtags, original_task_type):
+    """
+    Filter tasks based on hashtags, excluding specified task types.
+    """
+    if "all" in hashtags:
+        return [
+            task
+            for task in tasks
+            if task["task_type_name"].lower() != \
+                original_task_type["name"].lower()
+        ]
+    else:
+        hashtag_map = {
+            hashtag: True
+            for hashtag in hashtags 
+            if hashtag != original_task_type["name"].lower()
+        }
+        return [
+            task
+            for task in tasks
+            if hashtag_map.get(task["task_type_name"].lower(), False)
+        ]
+
+
+def add_attachments_to_comment(comment, files, reply_id=None):
     """
     Create an attachment entry and for each given uploaded files and tie it
     to given comment.
     """
-    comment["attachment_files"] = []
+    if comment.get("attachment_files", None) is None:
+        comment["attachment_files"] = []
+    new_attachment_files = []
     for uploaded_file in files.values():
         try:
-            attachment_file = create_attachment(comment, uploaded_file)
-            comment["attachment_files"].append(attachment_file)
-        except IntegrityError:
             attachment_file = create_attachment(
-                comment, uploaded_file, randomize=True
+                comment, uploaded_file, reply_id=reply_id
             )
             comment["attachment_files"].append(attachment_file)
-    return comment
+            new_attachment_files.append(attachment_file)
+        except IntegrityError:
+            attachment_file = create_attachment(
+                comment, uploaded_file, randomize=True, reply_id=reply_id
+            )
+            comment["attachment_files"].append(attachment_file)
+            new_attachment_files.append(attachment_file)
+    return comment, new_attachment_files
